#[non_exhaustive]pub enum Request {
CreateDataSource {
id: New<WlDataSource>,
},
GetDataDevice {
id: New<WlDataDevice>,
seat: WlSeat,
},
Release,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CreateDataSource
create a new data source
Create a new data source.
Fields

id: New<WlDataSource>data source to create
GetDataDevice
create a new data device
Create a new data device for a given seat.
Release
destroy wl_data_device_manager
This request destroys the wl_data_device_manager. This has no effect on any other objects.
This is a destructor, once received this object cannot be used any longer. Only available since version 4 of the interface
Implementations